@@ -20,6 +20,7 @@
 #import "VLCAppDelegate.h"
 #import "VLC-Swift.h"
 #import "VLCAppSceneDelegate.h"
+#import "VLCMLMedia+isWatched.h"
 
 @interface VLCAppDelegate ()
 {
@@ -61,6 +62,7 @@
                                   kVLCSettingBrightnessGesture : @(YES),
                                   kVLCSettingSeekGesture : @(YES),
                                   kVLCSettingCloseGesture : @(YES),
+                                  kVLCSettingPlaybackLongTouchSpeedUp : @(YES),
                                   kVLCSettingVideoFullscreenPlayback : @(YES),
                                   kVLCSettingContinuePlayback : @(1),
                                   kVLCSettingContinueAudioPlayback : @(1),
@@ -157,6 +159,8 @@
     NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
     [defaults setInteger:([defaults integerForKey:kVLCNumberOfLaunches] + 1) forKey:kVLCNumberOfLaunches];
 
+    [self recoverLastPlayingMedia];
+
     return YES;
 }
 
@@ -251,6 +255,8 @@
 
     VLCFavoriteService *fs = [[VLCAppCoordinator sharedInstance] favoriteService];
     [fs storeContentSynchronously];
+
+    [self savePlayingMediaIdentifier];
 }
 
 - (void)application:(UIApplication *)application performActionForShortcutItem:(UIApplicationShortcutItem *)shortcutItem completionHandler:(void (^)(BOOL))completionHandler
@@ -312,4 +318,32 @@
 {
 }
 
+#pragma mark - Recover last playing media
+
+- (void)savePlayingMediaIdentifier {
+    VLCMedia *currentMedia = [[VLCPlaybackService sharedInstance] currentlyPlayingMedia];
+    VLCMLIdentifier identifier = -1;
+
+    if (currentMedia) {
+        VLCMLMedia *libraryMedia = [VLCMLMedia mediaForPlayingMedia:currentMedia];
+        identifier = libraryMedia.identifier;
+    }
+
+    [[NSUserDefaults standardUserDefaults] setInteger:identifier forKey:kVLCLastPlayedMediaIdentifier];
+}
+
+- (void)recoverLastPlayingMedia {
+    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+    VLCMLIdentifier identifier = [defaults integerForKey:kVLCLastPlayedMediaIdentifier];
+    VLCMLMedia *media = [[[VLCAppCoordinator sharedInstance] mediaLibraryService] mediaFor:identifier];
+
+    // If media exists and not watched, recover it.
+    if (media && ![media isWatched]) {
+        [[VLCPlaybackService sharedInstance] playMedia:media openInMiniPlayer:YES];
+
+        // only recover a given media once
+        [defaults setInteger:-1 forKey:kVLCLastPlayedMediaIdentifier];
+    }
+}
+
 @end
