@@ -314,6 +314,7 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
     case backwardSkipLength
     case forwardSkipLengthSwipe
     case backwardSkipLengthSwipe
+    case longTouchToSpeedUp
 
     var containsInfobutton: Bool { return false }
 
@@ -341,6 +342,8 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return false
         case .backwardSkipLengthSwipe:
             return false
+        case .longTouchToSpeedUp:
+            return true
         }
     }
 
@@ -383,6 +386,8 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_PLAYBACK_SKIP_FORWARD_SWIPE"
         case .backwardSkipLengthSwipe:
             return "SETTINGS_PLAYBACK_SKIP_BACKWARD_SWIPE"
+        case .longTouchToSpeedUp:
+            return "SETINGS_LONG_TOUCH_SPEED_UP"
         }
     }
 
@@ -412,6 +417,8 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return kVLCSettingPlaybackForwardSkipLengthSwipe
         case .backwardSkipLengthSwipe:
             return kVLCSettingPlaybackBackwardSkipLengthSwipe
+        case .longTouchToSpeedUp:
+            return kVLCSettingPlaybackLongTouchSpeedUp
         }
     }
 }
@@ -489,6 +496,7 @@ enum VideoOptions: Int, CaseIterable, SectionType {
 }
 
 enum SubtitlesOptions: Int, CaseIterable, SectionType {
+    case disableSubtitles
     case font
     case relativeFontSize
     case useBoldFont
@@ -497,6 +505,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var description: String {
         switch self {
+        case .disableSubtitles:
+            return "SETTINGS_SUBTITLES_DISABLE"
         case .font:
             return "SETTINGS_SUBTITLES_FONT"
         case .relativeFontSize:
@@ -512,6 +522,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var containsSwitch: Bool {
         switch self {
+        case .disableSubtitles:
+            return true
         case .font:
             return false
         case .relativeFontSize:
@@ -527,6 +539,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var subtitle: String? {
         switch self {
+        case .disableSubtitles:
+            return "SETTINGS_SUBTITLES_DISABLE_LONG"
         case .font:
             return "Arial"
         case .relativeFontSize:
@@ -542,6 +556,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
 
     var preferenceKey: String? {
         switch self {
+        case .disableSubtitles:
+            return kVLCSettingDisableSubtitles
         case .font:
             return kVLCSettingSubtitlesFont
         case .relativeFontSize:
